<p align="center">
  <img width="260" src="https://raw.githubusercontent.com/bcarry/ska/main/docs/_static/logo_ska_light.png">
</p>

# ska - Spectral-Kit for Asteroids

Suites of tools to compute colors from spectra or reflectance spectra using the
[SVO Filter Service](http://svo2.cab.inta-csic.es/theory/fps/index.php?mode=voservice)
in different photometric system: Vega, AB, ST.

# Documentation

Check out the documentation at [https://space-ska.readthedocs.io](https://space-ska.readthedocs.io/en/latest/)
